lipyphilic CHANGELOG
====================

0.3.0 (2021-02-26)
------------------

* Fix neighbour calculation for non-sequential residue indices
  Fixes #11
* Added a tool to calculate interleaflet registration

0.2.0 (2021-02-23)
------------------

* Improved documentation
* Add method to count number of each neighbour type
* Add functionality to find neighbouring lipids

0.1.0 (2021-02-17)
------------------

* Add functionality to find flip-flop events in bilayers
* Add functionality to calculate area per lipid
* Add functionality to find assign lipids to leaflets in a bilayer


0.0.0 (2021-02-08)
------------------

* First release on PyPI.
